-- vim: ts=2 sw=2 ai et enc=utf8 fenc=utf8

local locale = GetLocale ()

-- Mandatory pet family localized strings.
-- These MUST MATCH what UnitCreatureFamily() returns.
local P
if locale == "enUS" or locale == "enGB" then
  P = RaidChecklistPetFamilies
  RaidChecklistSupportedLocale = true
else
  -- Set up a defaults table other locales can use as a fallback
  P = {}
  RaidChecklistPetFamiliesUS = P
  setmetatable (RaidChecklistPetFamilies, { __index = P })
end

P.BAT         = "Bat"
P.BEAR        = "Bear"
P.BEETLE      = "Beetle"
P.BIRDOFPREY  = "Bird of Prey"
P.BOAR        = "Boar"
P.CARRIONBIRD = "Carrion Bird"
P.CAT         = "Cat"
P.CHIMAERA    = "Chimaera"
P.COREHOUND   = "Core Hound"
P.CRAB        = "Crab"
P.CROCOLISK   = "Crocolisk"
P.DEVILSAUR   = "Devilsaur"
P.DOG         = "Dog"
P.DOOMGUARD   = "Doomguard"
P.DRAGONHAWK  = "Dragonhawk"
P.FELGUARD    = "Felguard"
P.FELHUNTER   = "Felhunter"
P.FOX         = "Fox"
P.GHOUL       = "Ghoul"
P.GORILLA     = "Gorilla"
P.HYDRA       = "Hydra"
P.HYENA       = "Hyena"
P.IMP         = "Imp"
P.MONKEY      = "Monkey"
P.MOTH        = "Moth"
P.NETHERRAY   = "Nether Ray"
P.RAPTOR      = "Raptor"
P.RAVAGER     = "Ravager"
P.RHINO       = "Rhino"
P.SCORPID     = "Scorpid"
P.SERPENT     = "Serpent"
P.SHALESPIDER = "Shale Spider"
P.SILITHID    = "Silithid"
P.SPIDER      = "Spider"
P.SPIRITBEAST = "Spirit Beast"
P.SPOREBAT    = "Sporebat"
P.SUCCUBUS    = "Succubus"
P.TALLSTRIDER = "Tallstrider"
P.TURTLE      = "Turtle"
P.VOIDWALKER  = "Voidwalker"
P.WARPSTALKER = "Warp Stalker"
P.WASP        = "Wasp"
P.WATERELEMENTAL = "Water Elemental"
P.WINDSERPENT = "Wind Serpent"
P.WOLF        = "Wolf"
P.WORM        = "Worm"



-- Optional strings
local L
if locale == "enUS" or locale == "enGB" then
  L = RaidChecklistStrings
else
  -- Set up a defaults table other locales can use as a fallback
  L = {}
  RaidChecklistStringsUS = L
  setmetatable (RaidChecklistStrings, { __index = L })
end

-- Colorized class names
L.HUNTER      = ClassColorString ("HUNTER")     .. "Hunter"
L.WARRIOR     = ClassColorString ("WARRIOR")    .. "Warrior"
L.DEATHKNIGHT = ClassColorString ("DEATHKNIGHT").. "Death Knight"
L.PRIEST      = ClassColorString ("PRIEST")     .. "Priest"
L.SHAMAN      = ClassColorString ("SHAMAN")     .. "Shaman"
L.PALADIN     = ClassColorString ("PALADIN")    .. "Paladin"
L.DRUID       = ClassColorString ("DRUID")      .. "Druid"
L.WARLOCK     = ClassColorString ("WARLOCK")    .. "Warlock"
L.ROGUE       = ClassColorString ("ROGUE")      .. "Rogue"
L.MAGE        = ClassColorString ("MAGE")       .. "Mage"

-- Talent trees
L.AFFLICTION    = "(Affliction)"
L.ARCANE        = "(Arcane)"
L.ARMS          = "(Arms)"
L.ASSASSINATION = "(Assassination)"
L.BALANCE       = "(Balance)"
L.BEASTMASTER   = "(BeastMaster)"
L.BLOOD         = "(Blood)"
L.COMBAT        = "(Combat)"
L.DEMONOLOGY    = "(Demonology)"
L.DESTRUCTION   = "(Destruction)"
L.DRUIDBEAR     = "(Bear)"
L.ELEMENTAL     = "(Elemental)"
L.ENHANCEMENT   = "(Enhancement)"
L.FERAL         = "(Feral)"
L.FIRE          = "(Fire)"
L.FROST         = "(Frost)"
L.FURY          = "(Fury)"
L.MARKSMAN      = "(Marksman)"
L.PROTECTION    = "(Protection)"
L.RESTORATION   = "(Restoration)"
L.RETRIBUTION   = "(Retribution)"
L.SHADOW        = "(Shadow)"
L.SUBTLETY      = "(Subtlety)"
L.SURVIVAL      = "(Survival)"
L.UNHOLY        = "(Unholy)"
L.HOLY          = "(Holy)"
L.DISCIPLINE    = "(Discipline)"

L.PET = " pet: "
L.MISSINGTALENTS = "Talents not yet inspected for:"
L.OFFLINE = "(offline)"
L.INSPECTQUEUE = "Yet to inspect:"
L.NOWINSPECTING = "Now inspecting:"

-- Race/class combos
L.BLOODELF = "|rBlood Elf"
L.BLOODELF_ROGUE   = L.BLOODELF.." "..L.ROGUE
local SEP = "|r/"
L.BLOODELF_CASTER  = L.BLOODELF.." "..L.DRUID..SEP..L.MAGE..SEP..L.PALADIN..SEP..L.PRIEST..SEP..L.SHAMAN..SEP..L.WARLOCK
L.BLOODELF_WARRIOR = L.BLOODELF.." "..L.WARRIOR
L.BLOODELF_DEATHKNIGHT = L.BLOODELF.." "..L.DEATHKNIGHT
L.BLOODELF_HUNTER = L.BLOODELF.." "..L.HUNTER
L.RACIAL = select (2, GetSpellInfo (25046))

-- List headers
L.BUFFS    = "Buffs"
L.DEBUFFS  = "Debuffs"
L.CC    = "Crowd Control"
L.MISC  = "Miscellaneous"
L.HUNTERPETABILITIES = "Hunter Pet Abilities"
L.WARLOCKPETABILITIES = "Warlock Pet Abilities"
L.TOTEMS_EARTH = "Earth Totems"
L.TOTEMS_FIRE = "Fire Totems"
L.TOTEMS_WATER = "Water Totems"
L.TOTEMS_AIR = "Air Totems"
L.WARRIORSHOUTS = "Shouts"
L.PALADINAURAS = "Auras"
L.PALADINBLESSINGS = "Blessings"
L.AVAILABLEFROM = "Available from:"
L.PROVIDEDBY = "Provided by:"
L.NOBODY = "<nobody>"

-- Buffs & debuff names
L.CRIT            = "+5% Critical Chance"
L.ATTACKPWR       = "+10% Attack Power"
L.SPELLPWR6       = "+6% Spell Power"
L.SPELLPWR10      = "+10% Spell Power"
L.PHYSHASTE       = "+10% Physical Haste"
L.SPELLHASTE      = "+5% Spell Haste"
L.STATS           = "+5% All Primary Stats"
L.ALLDMG          = "+3% All Damage"
L.AGISTR          = "Increased Agi/Str"
L.STAM            = "Increased Stamina"
L.BLOODLUST       = "Bloodlust/Heroism"
L.MANA            = "Increased Mana Pool"
L.MANAREGEN       = "Increased Mana Regen"
L.BURSTMANA       = "Burst Replenishment"
L.REPLENISHMENT   = "Replenishment"
L.ARMOR           = "Increased Armor"
L.PUSHBACKRES     = "Resist (Spell Pushback)"
L.FIREFROSTRES    = "Resist (Fire/Frost)"
L.NATURERES       = "Resist (Nature)"
L.SHADOWRES       = "Resist (Shadow)"

L.SPELLCRIT       = "+5% Spell Crit. Vulnerability"
L.PHYSDMGTAKEN    = "+4% Physical Dmg Taken"
L.SPELLDMGTAKEN   = "+8% Spell Dmg Taken"
L.BLEEDDMGTAKEN   = "+30% Bleed Dmg Taken"
L.ATTACKSPD       = "Decreased Attack Speed"
L.CASTSPD         = "Decreased Cast Speed"
L.DEMOROAR        = "Decreased Physical Dmg"
L.SUNDER          = "-12% Armor"
L.MORTALSTRIKE    = "-10% Healing Received"

-- Dispels
L.DISPELS         = "Dispels/Cures"
L.OFFMAGIC        = "Dispel Magic (offensive)"
L.DEFMAGIC        = "Dispel Magic (defensive)"
L.DISEASE         = "Cure Disease"
L.POISON          = "Cleanse Poison"
L.CURSE           = "Remove Curse"
L.ENRAGE          = "Soothe Enrage (offensive)"

-- CC
L.CCBEASTS        = "General - Beasts"
L.CCDEMONS        = "General - Demons"
L.CCDRAGONKIN     = "General - Dragonkin"
L.CCELEMENTALS    = "General - Elementals"
L.CCGIANTS        = "General - Giants"
L.CCHUMANOIDS     = "General - Humanoids"
L.CCUNDEAD        = "General - Undead"
L.CCANY           = "General - Any"
L.FEARBEASTS      = "Fear - Beasts"
L.FEARUNDEAD      = "Fear - Demons & Undead"
L.FEARANY         = "Fear - Any"

-- Misc
L.KNOCKBACK       = "Knockback (cooldown <= 45s)"
L.INTERRUPT       = "Interrupt (cooldown <= 30s)"
L.INTERRUPT2      = "Interrupt (cooldown > 30s)"
L.SNARE           = "Snare/Slow (chain-castable)"
L.AOESNARE        = "Area Snare/Slow (chain-castable)"
L.ROOT            = "Root (chain-castable)"
L.DISARM          = "Disarm"

-- Cardinality
L[0]              = "" -- Don't show a number for missing abilities
L[1]              = "" -- If there's only one, we don't really need to show a number for it (in fact it looks silly when soloing)
L[2]              = "(2)"
L[3]              = "(3)"
L[4]              = "(4)"
L[5]              = "(5)"
L[6]              = "(6)"
L[7]              = "(7)"
L[8]              = "(8)"
L[9]              = "(9)"
L.MANY            = "(*)" -- Life is easier if we can keep things the same width (single digits). Of course, this might be a very western notion... feel free to educate me!

-- Detailed information window
L.DETAILS         = "Detailed ability information:"
L.TALENT          = "talent"
L.LEVEL           = "level"
L.SPECIALIZATION  = "specialization skill"

-- Configuration
L["Raid Checklist"] = "Raid Checklist"
L.SETTINGS = "Settings"
L.PROFILES = "Profiles"
L.ABOUT = "About"
L.CONFIG = "Configuration"
L.ANCHORLOCKED = "Locked"
L.ANCHORLOCKEDDESC = "Lock anchor button in place to prevent accidental moving of it."
L.SHOWANCHOR = "Show anchor button"
L.SHOWANCHORDESC = "When using DataBroker displays, it might not be necessary to display the main anchor button."
L.OPENDIRECTION = "List direction"
L.OPENDIRECTIONDESC = "Direction to open the checklist in, relative to the anchor button."
L.DOWNRIGHT = "Down, Right"
L.DOWNLEFT = "Down, Left"
L.UPRIGHT = "Up, Right"
L.UPLEFT = "Up, Left"
L.DETAILSSIDE = "Details panel side"
L.DETAILSSIDEDESC = "Side of the checklist to attach the detailed information panel to."
L.RIGHT = "Right"
L.LEFT = "Left"
L.RESETANCHOR = "Reset button position"
L.RESETANCHORDESC = "Repositions the anchor button to the center of the screen."
L.FILTERGROUPS = "To facilitate raid composition, abilities from members in the selected groups are marked in green. Abilities provided only by members in non-selected groups are marked in blue."
L.GROUP = "Group"
L.FONTSIZE = "Font size"
L.FONTSIZEDESC = "Size of the font to use in the checklist."
L.NORMAL = "Normal"
L.SMALL = "Small"
L.OPACITY = "List opacity"
L.OPACITYDESC = "Determines transparency of the checklist. A value of 0 means fully transparent, and a value of 1 fully opaque."
L.STDLIST = "Standard lists"
L.STDLISTDESC = "Most commonly used checklists. Automatically adjust to the class of your character."
L.ADVLIST = "Advanced lists"
L.ADVLISTDESC = "Per-class customized checklists, offering choices in both content and layout."

L.LIST_RAIDLEADER_BRIEF = "Raid Leader (Brief)"
L.LIST_RAIDLEADER_FULL = "Raid Leader (Full)"
L.LIST_PERSONAL_BRIEF = "Personal (Brief)"
L.LIST_PERSONAL_FULL = "Personal (Full)"
L.LISTSUFFIX_B = " (Brief)"
L.LISTSUFFIX_F = " (Full)"
L.LISTSUFFIX_P = " (Pets only)"
L.LISTSUFFIX_CB = " (Brief/Compact)"
L.LISTSUFFIX_CF = " (Full/Compact)"

L.LDBTOOLTIP = "Left-click to toggle raid checklist.\nRight-click for configuration options."

-- Help section
L.HELP = "Help / F.A.Q."
L.HELP_INTRO_HDR = "Introduction - What does it do?"
L.HELP_INTRO = "RaidChecklist provides an overview of whether key abilities are available within the current group/raid. It is intended both as an aid for putting together balanced raid groups and as a way to give individual players a quick reference of abilities. With RaidChecklist you get an up-to-date view over the potential abilities in the group or raid.\n\nRaidChecklist also functions like an in-game database of raid-related abilities, organized by category and effect.\n\nWhat RaidChecklist is not, is a buff/debuff monitor. It does not track actual use of abilities, or provide uptime statistics of them. Such tasks are already handled by other addons, such as PallyPower or Recount, not to mention the off-line combat log analyzers.\n\n"
L.HELP_COLORS_HDR = "What do the colors mean?"
L.HELP_COLORS = "Each entry in the checklist is color-coded according to its status:\n\n|cffb4b4b4Gray|r - The ability is not currently provided by anyone.\n\n|cff0066ffBlue|r - Someone has the ability to provide this ability, but is in a raid sub-group that has been filtered out. To make the ability available, either move that player to an included sub-group, or adjust the raid group filtering from the settings panel.\n\n|cff00ff00Green|r - At least one player is currently providing the ability.\n\n|cffff0000Red|r - All players providing the ability are offline.\n\n"
L.HELP_FLAG_HDR = "What does the |TInterface\\AddOns\\RaidChecklist\\Textures\\greenflag:0|t flag mean?"
L.HELP_FLAG = "The flag is an indication that only a single player, you, can provide that particular ability. That makes it your responsibility to use it!\n\n"
L.HELP_HUNTERPETS_HDR = "How are hunter pets handled?"
L.HELP_HUNTERPETS = "Hunter pets are treated as an extension of the player, and RaidChecklist automatically updates to take into account any abilities provided by a summoned pet, be it yours or a group member's.\n\nFor hunters, RaidChecklist provides additional functionality. The first time you visit a stable master RaidChecklist will check what pets are \"on call\", and remember them. Abilities provided by the on-call pets are listed in blue in your checklist (but not anybody else's). If you see a blue |TInterface\\AddOns\\RaidChecklist\\Textures\\blueflag:0|t flag in your checklist, that is a good indication that you should consider calling the pet providing that ability, as you are the only one capable of providing it in the current group or raid.\n\n"
L.HELP_LINKING_HDR = "Can you link the abilities to chat?"
L.HELP_LINKING = "Yes! Simply open the details pane by clicking on any entry in the checklist, then shift-click the ability you want to link.\n\n"
L.HELP_COMMANDS_HDR = "What chat commands are available?"
L.HELP_COMMANDS = "RaidChecklist provides the commands /raidchecklist and /rcl to toggle the checklist with. There is also a keybind available for that action.\n\n"
L.HELP_TALENTSCAN_HDR = "Why do talents appear even when out of range?"
L.HELP_TALENTSCAN = "Normally RaidChecklist has to wait until a player comes in range to inspect the talents of said player.\n\nHowever, RaidChecklist uses an add-on component called \"LibGroupTalents\", which provides a way for players to share talent information without a need for inspections. Talents for any player running RaidChecklist or other add-on including that component will become visible automatically.\n\n"
L.HELP_INCOMBAT_HDR = "Does RaidChecklist update while in combat?"
L.HELP_INCOMBAT = "That depends. RaidChecklist doesn't continuously scan for changes to the group setup the way some add-ons do. Instead it listens for game events which indicate that something of note has changed, such as a pet being summoned, someone doing a talent-respec, a player leaving the group, et.c. If such an event does happen while in combat then RaidChecklist updates, otherwise it doesn't.\n\nTypically any actions performed by RaidChecklist will be so minimal they aren't even noticeable. The worst case scenario is probably if you join a raid in progress and accept a warlock's summon straight into combat. All of a sudden a lot of players will become available for talent inspection, which might possibly impact game performance if you are on a slow enough connection. Chances are it will still be imperceptible though.\n\n"


-- Keybinding
BINDING_NAME_RAIDCHECKLIST_TOGGLE = "Toggle Raid Checklist"
BINDING_HEADER_RAIDCHECKLIST = L["Raid Checklist"]

